@@ -2,7 +2,9 @@ package X11::Xlib::XSetWindowAttributes;
 require X11::Xlib::Struct;
 __END__
 
-(most methods are inherited or XS, so there is no need to load this package file)
+=head1 NAME
+
+X11::Xlib::XSetWindowAttributes - Struct defining window attributes
 
 =head1 DESCRIPTION
 
@@ -34,4 +36,20 @@ or L<XChangeWindowAttributes|X11::Xlib/XChangeWindowAttributes>.
 
 See parent class L<X11::Xlib::Struct>
 
+=head1 AUTHOR
+
+Olivier Thauvin, E<lt>nanardon@nanardon.zarb.orgE<gt>
+
+Michael Conrad, E<lt>mike@nrdvana.netE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2009-2010 by Olivier Thauvin
+
+Copyright (C) 2017 by Michael Conrad
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
+at your option, any later version of Perl 5 you may have available.
+
 =cut
